# Frequenz Python SDK Release Notes

## Upgrading

- The minimum required version of `frequenz-microgrid-component-graph` is now `0.3.4`.  This reverts the formula generation to what it was like before the migration to the external component graph library.  So
    * in component formulas, meters get used as primary sources and inverters, ev chargers, etc. as fallback sources.
    * consumer formula are generated by excluding producer and battery powers from the grid power, or when there is no grid meter, by adding all the non battery and producer meters.

## New Features

- The SDK's data pipeline now supports retrieving telemetry from CHPs.

## Bug Fixes

- Fixed an off-by-one calculation in `OrderedRingBuffer.count_covered` by switching to integer timedelta division, ensuring accurate sample counting for all window sizes and sampling periods.
- Component IDs are validated during creation of battery, pv and ev charger pools, so that errors are caught early and we don't end up getting cryptic failures from somewhere else.
